"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
function Session(base) {
    const table = base.table('Session');
    return {
        getSessionBySessionToken: (0, utils_1.getSessionBySessionToken)(table),
        createSession: async ({ sessionToken, userId, expires, }) => {
            const sessionFields = {
                sessionToken,
                userId: [userId],
                expires: expires.toISOString(),
            };
            return table
                .create([{ fields: sessionFields }])
                .then(utils_1.getRecordsFields)
                .then((fields) => ({
                ...fields,
                userId: userId[0],
                expires: new Date(expires),
            }));
        },
        updateSession: async (newSession) => {
            var _a;
            const { sessionToken } = newSession;
            if (!sessionToken)
                return null;
            const session = await (0, utils_1.getSessionBySessionToken)(table)(sessionToken);
            if (!(session === null || session === void 0 ? void 0 : session.id))
                return null;
            return table
                .update(session.id, {
                ...newSession,
                expires: (_a = newSession.expires) === null || _a === void 0 ? void 0 : _a.toISOString(),
            })
                .then(utils_1.getRecordFields)
                .catch((_e) => null);
        },
        getSession: (sessionId) => table
            .find(sessionId)
            .then(utils_1.getRecordFields)
            .then((fields) => {
            if (!fields || !fields.expires)
                return null;
            return {
                sessionToken: fields.sessionToken,
                userId: Array.isArray(fields.userId)
                    ? fields === null || fields === void 0 ? void 0 : fields.userId[0]
                    : fields.userId,
                expires: new Date(fields.expires.toString()),
            };
        })
            .catch((e) => {
            if (e.error === 'NOT_FOUND')
                return null;
            throw e;
        }),
        deleteSession: (sessionId) => table.destroy(sessionId),
    };
}
exports.default = Session;
