"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
function User(base) {
    const userTable = base.table('User');
    const accountTable = base.table('Account');
    const sessionTable = base.table('Session');
    return {
        getUserById: async (userId) => userTable
            .find(userId)
            .then((r) => (0, utils_1.getRecordFields)(r))
            .then(convertAirtableUserToAdapterUser)
            .catch((e) => {
            if (e.error === 'NOT_FOUND')
                return null;
            throw e;
        }),
        getUserByEmail: (email) => userTable
            .select({ filterByFormula: `{email}='${email}'` })
            .all()
            .then((r) => (0, utils_1.getRecordsFields)(r))
            .then(convertAirtableUserToAdapterUser),
        createUser: async ({ name, email, image, emailVerified }) => {
            const userFields = {
                name: name === null || name === void 0 ? void 0 : name.toString(),
                email: email === null || email === void 0 ? void 0 : email.toString(),
                image: image === null || image === void 0 ? void 0 : image.toString(),
                emailVerified: emailVerified === null || emailVerified === void 0 ? void 0 : emailVerified.toISOString(),
            };
            return userTable
                .create(userFields)
                .then((r) => (0, utils_1.getRecordFields)(r))
                .then(convertAirtableUserToAdapterUser);
        },
        updateUser: async (user) => {
            const { id, ...userFields } = user;
            if (!id)
                return null;
            return (userTable
                .update(id, userFields)
                .then(utils_1.getRecordFields));
        },
        deleteUser: async (userId) => {
            if (!userId)
                return null;
            await sessionTable
                .select({ filterByFormula: `{userId}='${userId}'` })
                .all()
                .then((records) => Promise.all(records.map((record) => record.destroy())));
            await accountTable
                .select({ filterByFormula: `{userId}='${userId}'` })
                .all()
                .then((records) => Promise.all(records.map((record) => record.destroy())));
            await userTable
                .destroy(userId)
                .then((fields) => ({ ...fields, Account: undefined }));
        },
    };
}
exports.default = User;
const convertAirtableUserToAdapterUser = async (user) => {
    if (!user)
        return null;
    const { id, name, email, image, emailVerified } = user;
    return {
        id,
        name,
        email,
        image,
        emailVerified: emailVerified ? new Date(emailVerified === null || emailVerified === void 0 ? void 0 : emailVerified.toString()) : null,
    };
};
